Package: rversions
Title: Query 'R' Versions, Including 'r-release' and 'r-oldrel'
Version: 3.0.0
Authors@R: 
    c(person(given = "Gábor",
             family = "Csárdi",
             role = c("aut", "cre"),
             email = "csardi.gabor@gmail.com"),
      person(given = "Jeroen",
             family = "Ooms",
             role = "ctb",
             email = "jeroen.ooms@stat.ucla.edu"),
      person(given = "R Consortium",
             role = "fnd"),
      person("Posit Software, PBC", role = c("cph", "fnd"),
             comment = c(ROR = "03wc8by49")))
Description: Query the main 'R' 'SVN' repository to find the
    versions 'r-release' and 'r-oldrel' refer to, and also all previous
    'R' versions and their release dates.
License: MIT + file LICENSE
URL: https://github.com/r-hub/rversions,
        https://r-hub.github.io/rversions/
BugReports: https://github.com/r-hub/rversions/issues
Imports: curl
Suggests: pillar, testthat (>= 3.0.0), webfakes, withr
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-10-09 13:47:01 UTC; gaborcsardi
Author: Gábor Csárdi [aut, cre],
  Jeroen Ooms [ctb],
  R Consortium [fnd],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2025-10-09 14:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 15:58:46 UTC; unix
