# Generated by roxygen2: do not edit by hand

export(available)
export(current_r_platform)
export(linux_distros)
export(r_oldrel)
export(r_release)
export(r_release_macos)
export(r_release_tarball)
export(r_release_win)
export(r_versions)
export(resolve)
export(rtools_versions)
importFrom(curl,curl_fetch_memory)
