# r_release_win

    Code
      r_release_win()
    Output
      # A data frame: 1 x 5
        version date                nickname          semver     URL                                                      
        <chr>   <dttm>              <chr>             <pckg_vrs> <chr>                                                    
      1 4.5.1   2025-06-13 07:12:01 Great Square Root 4.5.1      https://cran.rstudio.com/bin/windows/base/R-4.5.1-win.exe

