# available, macos

    Code
      available("macos")
    Output
      # A data frame: 20 x 5
         version date                semver     type    url                                                                     
         <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                                   
       1 4.1.0   2021-05-18 07:05:22 4.1.0      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.1.0-arm64.pkg
       2 4.1.1   2021-08-10 07:05:06 4.1.1      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.1.1-arm64.pkg
       3 4.1.2   2021-11-01 08:05:12 4.1.2      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.1.2-arm64.pkg
       4 4.1.3   2022-03-10 08:05:38 4.1.3      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.1.3-arm64.pkg
       5 4.2.0   2022-04-22 07:05:41 4.2.0      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.2.0-arm64.pkg
       6 4.2.1   2022-06-23 07:05:33 4.2.1      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.2.1-arm64.pkg
       7 4.2.2   2022-10-31 08:05:54 4.2.2      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.2.2-arm64.pkg
       8 4.2.3   2023-03-15 08:06:01 4.2.3      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.2.3-arm64.pkg
       9 4.3.0   2023-04-21 07:06:14 4.3.0      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.3.0-arm64.pkg
      10 4.3.1   2023-06-16 07:06:07 4.3.1      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.3.1-arm64.pkg
      11 4.3.2   2023-10-31 08:07:42 4.3.2      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.3.2-arm64.pkg
      12 4.3.3   2024-02-29 08:07:53 4.3.3      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.3.3-arm64.pkg
      13 4.4.0   2024-04-24 04:07:56 4.4.0      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.4.0-arm64.pkg
      14 4.4.1   2024-06-14 07:08:17 4.4.1      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.4.1-arm64.pkg
      15 4.4.2   2024-10-31 08:09:02 4.4.2      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.4.2-arm64.pkg
      16 4.4.3   2025-02-28 08:08:59 4.4.3      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.4.3-arm64.pkg
      17 4.5.0   2025-04-11 08:51:39 4.5.0      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.5.0-arm64.pkg
      18 4.5.1   2025-06-13 07:12:01 4.5.1      release https://cran.rstudio.com/bin/macosx/big-sur-arm64/base/R-4.5.1-arm64.pkg
      19 4.5.1   NA                  4.5.1      patched https://mac.r-project.org/big-sur/last-success/R-4.5-branch-arm64.pkg   
      20 4.6.0   NA                  4.6.0      devel   https://mac.r-project.org/big-sur/last-success/R-devel-arm64.pkg        

# available, macos-x86_64

    Code
      available("macos-x86_64")
    Output
      # A data frame: 74 x 5
         version date                semver     type    url                                                            
         <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                          
       1 2.10.0  2009-10-26 09:02:22 2.10.0     release https://cran-archive.r-project.org/bin/macosx/base/R-2.10.0.pkg
       2 2.10.1  2009-12-14 10:28:24 2.10.1     release https://cran-archive.r-project.org/bin/macosx/base/R-2.10.1.pkg
       3 2.11.0  2010-04-22 08:11:21 2.11.0     release https://cran-archive.r-project.org/bin/macosx/base/R-2.11.0.pkg
       4 2.11.1  2010-05-31 08:10:25 2.11.1     release https://cran-archive.r-project.org/bin/macosx/base/R-2.11.1.pkg
       5 2.12.0  2010-10-15 08:41:57 2.12.0     release https://cran-archive.r-project.org/bin/macosx/base/R-2.12.0.pkg
       6 2.12.1  2010-12-16 09:12:04 2.12.1     release https://cran-archive.r-project.org/bin/macosx/base/R-2.12.1.pkg
       7 2.12.2  2011-02-25 11:07:19 2.12.2     release https://cran-archive.r-project.org/bin/macosx/base/R-2.12.2.pkg
       8 2.13.0  2011-04-13 08:31:27 2.13.0     release https://cran-archive.r-project.org/bin/macosx/base/R-2.13.0.pkg
       9 2.13.1  2011-07-08 09:37:08 2.13.1     release https://cran-archive.r-project.org/bin/macosx/base/R-2.13.1.pkg
      10 2.13.2  2011-09-30 07:05:56 2.13.2     release https://cran-archive.r-project.org/bin/macosx/base/R-2.13.2.pkg
      # i 64 more rows

# available, windows

    Code
      utils::tail(available("windows"))
    Output
      # A data frame: 6 x 5
        version date                semver     type    url                                                                
      * <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                              
      1 4.4.2   2024-10-31 08:09:02 4.4.2      release https://cran.rstudio.com/bin/windows/base/old/4.4.2/R-4.4.2-win.exe
      2 4.4.3   2025-02-28 08:08:59 4.4.3      release https://cran.rstudio.com/bin/windows/base/old/4.4.3/R-4.4.3-win.exe
      3 4.5.0   2025-04-11 08:51:39 4.5.0      release https://cran.rstudio.com/bin/windows/base/old/4.5.0/R-4.5.0-win.exe
      4 4.5.1   2025-06-13 07:12:01 4.5.1      release https://cran.rstudio.com/bin/windows/base/old/4.5.1/R-4.5.1-win.exe
      5 4.5.1   NA                  4.5.1      patched https://cran.rstudio.com/bin/windows/base/R-4.5.1patched-win.exe   
      6 4.6.0   NA                  4.6.0      devel   https://cran.rstudio.com/bin/windows/base/R-devel-win.exe          

# available, windows-aarch64

    Code
      available("windows-aarch64")
    Output
      # A data frame: 8 x 5
        version date                semver     type    url                                                                                            
        <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                                                          
      1 4.4.0   2024-04-24 04:07:56 4.4.0      release https://github.com/r-hub/R/releases/download/v4.4.0/R-4.4.0-aarch64.exe                        
      2 4.4.1   2024-06-14 07:08:17 4.4.1      release https://github.com/r-hub/R/releases/download/v4.4.1/R-4.4.1-aarch64.exe                        
      3 4.4.2   2024-10-31 08:09:02 4.4.2      release https://github.com/r-hub/R/releases/download/v4.4.2/R-4.4.2-aarch64.exe                        
      4 4.4.3   2025-02-28 08:08:59 4.4.3      release https://github.com/r-hub/R/releases/download/v4.4.3/R-4.4.3-aarch64.exe                        
      5 4.5.0   2025-04-11 08:51:39 4.5.0      release https://github.com/r-hub/R/releases/download/v4.5.0/R-4.5.0-aarch64.exe                        
      6 4.5.1   2025-06-13 07:12:01 4.5.1      release https://github.com/r-hub/R/releases/download/v4.5.1/R-4.5.1-aarch64.exe                        
      7 4.5.1   NA                  4.5.1      patched https://github.com/r-hub/R/releases/download/vnext/R-next-patched-2025-09-24-r88904-aarch64.exe
      8 4.6.0   NA                  4.6.0      devel   https://github.com/r-hub/R/releases/download/vdevel/R-devel-2025-10-06-r88901-aarch64.exe      

# available, ubuntu

    Code
      utils::tail(available("linux-ubuntu-24.04"))
    Output
      # A data frame: 6 x 5
        version date                semver     type    url                                                        
      * <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                      
      1 4.4.2   2024-10-31 08:09:02 4.4.2      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.4.2_1_amd64.deb
      2 4.4.3   2025-02-28 08:08:59 4.4.3      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.4.3_1_amd64.deb
      3 4.5.0   2025-04-11 08:51:39 4.5.0      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.5.0_1_amd64.deb
      4 4.5.1   2025-06-13 07:12:01 4.5.1      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.5.1_1_amd64.deb
      5 4.5.1   NA                  4.5.1      patched https://cdn.posit.co/r/ubuntu-2404/pkgs/r-next_1_amd64.deb 
      6 4.6.0   NA                  4.6.0      devel   https://cdn.posit.co/r/ubuntu-2404/pkgs/r-devel_1_amd64.deb

# available, ubuntu aarch64

    Code
      utils::tail(available("aarch64-unknown-linux-ubuntu-24.04"))
    Output
      # A data frame: 6 x 5
        version date                semver     type    url                                                        
      * <chr>   <dttm>              <pckg_vrs> <chr>   <chr>                                                      
      1 4.4.2   2024-10-31 08:09:02 4.4.2      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.4.2_1_arm64.deb
      2 4.4.3   2025-02-28 08:08:59 4.4.3      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.4.3_1_arm64.deb
      3 4.5.0   2025-04-11 08:51:39 4.5.0      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.5.0_1_arm64.deb
      4 4.5.1   2025-06-13 07:12:01 4.5.1      release https://cdn.posit.co/r/ubuntu-2404/pkgs/r-4.5.1_1_arm64.deb
      5 4.5.1   NA                  4.5.1      patched https://cdn.posit.co/r/ubuntu-2404/pkgs/r-next_1_arm64.deb 
      6 4.6.0   NA                  4.6.0      devel   https://cdn.posit.co/r/ubuntu-2404/pkgs/r-devel_1_arm64.deb

