% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tarball.R
\name{r_release_tarball}
\alias{r_release_tarball}
\title{Latest release for which a source tarball is available for download}
\usage{
r_release_tarball()
}
\value{
A one row data frame, with columns \sQuote{version},
\sQuote{date}, \sQuote{URL} and \sQuote{nickname}.
}
\description{
\code{\link[=r_release]{r_release()}} works based on the SVN tags in the main R source code
repository. However, an SVN tag does not mean that the same version
is available for download. \code{r_release_tarball} returns the latest
version for which a source tarball is available.
}
\examples{
r_release()
r_release_tarball()
}
\seealso{
Other R downloads: 
\code{\link{r_release_macos}()},
\code{\link{r_release_win}()}
}
\concept{R downloads}
